@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "erlang" "28.3.3"
+(define-package "erlang" "20250827.800"
   "Major modes for editing and running Erlang."
   '((emacs "24.3"))
   :url "https://github.com/erlang/otp"
-  :commit "dfd646eef0dd6b1f3674a7b6c7c7ff944939139b"
-  :revdesc "OTP-28.3.3-0-gdfd646eef0dd"
+  :commit "ed8445a63861f510d21e27c9122e4fafa8039d9d"
+  :revdesc "ed8445a63861"
   :keywords '("erlang" "languages" "processes"))
